---
# This is a sample include file.
---

### Some Links

* [Link One](#)
* [Link Two](#)
* [Link Three](#)

### Some Text

Lorem ipsum dolor sit amet, consectetur adipiscing elit,
sed do eiusmod tempor incididunt ut labore et dolore magna
aliqua.
